using System;
using System.Runtime.InteropServices;
using System.Web.UI;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Serialization;

using Microsoft.SharePoint;
using Microsoft.SharePoint.WebControls;
using Microsoft.SharePoint.WebPartPages;

using Telerik.Web.UI;
using System.Collections.Generic;

namespace Telerik.SharePoint
{
    [Guid("b2741e1b-25a3-4f02-9822-a45c196e570b")]
    public class FileExplorerWebPart : System.Web.UI.WebControls.WebParts.WebPart
    {
        private RadFileExplorer fileExplorer = null;
        protected override void CreateChildControls()
        {
            base.CreateChildControls();
            ScriptManager sm = ScriptManager.GetCurrent(Page);
            if (sm == null)
            {
                //add a new script manager if one has not been registered yet.
                sm = new ScriptManager();
                sm.ID = "ScriptManager1";
                Controls.Add(sm);
            }
            fileExplorer = new RadFileExplorer();
            fileExplorer.ID = "RadFileExplorer1";
            Controls.Add(fileExplorer);
            fileExplorer.Configuration.ContentProviderTypeName = typeof(SPContentProvider).AssemblyQualifiedName;
            //CSS fix for MOSS in IE Quirks mode
            fileExplorer.Style.Add("overflow", "hidden");
            //fix for the ASP.NET AJAX UpdatePanel issue in MOSS
            Page.ClientScript.RegisterStartupScript(Page.GetType(), "AjaxUpdatePanelFix", "_spOriginalFormAction = document.forms[0].action; _spSuppressFormOnSubmitWrapper=true;", true);
        }

        protected override void OnInit(EventArgs e)
        {
            base.OnInit(e);
            EnsureChildControls();
        }
        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);
            SetFileExplorerPaths();
        }

        private SPListCollection RetrieveDocumentLibraries(SPWeb web)
        {
            SPListCollection documentLibraries = web.GetListsOfType(SPBaseType.DocumentLibrary);
            documentLibraries.ListsForCurrentUser = true;
            documentLibraries.IncludeRootFolder = true;
            SPContext.Current.Site.CatchAccessDeniedException = false;
            return documentLibraries;
        }

        private void SetFileExplorerPaths()
        {
            List<String> paths = new List<String>();
            //get a list of all SharePoint libraries in the current web
            SPListCollection docLibraries = RetrieveDocumentLibraries(SPContext.Current.Web);

            //remove libraries that should not be visible in the FileExplorer
            foreach (SPList list in docLibraries)
            {
                if (SPContentProvider.IsNotSystemFolder(list.RootFolder))
                {
                    paths.Add(list.RootFolder.ServerRelativeUrl);
                }
            }
            string[] convertedPaths = paths.ToArray();
            fileExplorer.Configuration.ViewPaths = convertedPaths;
            fileExplorer.Configuration.UploadPaths = fileExplorer.Configuration.ViewPaths;
            fileExplorer.Configuration.DeletePaths = fileExplorer.Configuration.ViewPaths;
        }
    }
}
